import { createApi } from "@reduxjs/toolkit/query/react";
import { baseQuery } from "../../app/apiBaseQuery";
import { Location } from "../../models/location";

export const locationApi = createApi({
  reducerPath: "locationApi",
  baseQuery,
  endpoints: (builder) => ({
    getLocations: builder.query<Location[], void>({
      query: () => "/locations",
    }),
    getLocationById: builder.query<Location, string>({
      query: (id) => `/locations/${id}`,
    }),
    createLocation: builder.mutation<Location, Partial<Location>>({
      query: (newLocation) => ({
        url: "/locations",
        method: "POST",
        body: newLocation,
      }),
    }),
    updateLocation: builder.mutation<
      Location,
      { id: string; location: Partial<Location> }
    >({
      query: ({ id, location }) => ({
        url: `/locations/${id}`,
        method: "PUT",
        body: location,
      }),
    }),
    deleteLocation: builder.mutation<void, string>({
      query: (id) => ({
        url: `/locations/${id}`,
        method: "DELETE",
      }),
    }),
  }),
});

export const {
  useGetLocationsQuery,
  useGetLocationByIdQuery,
  useCreateLocationMutation,
  useUpdateLocationMutation,
  useDeleteLocationMutation,
} = locationApi;
